==> huaweicloudsdkscm-3.1.141-py2.py3-none-any.whl: huaweicloudsdkscm/v3/model/show_csr_private_key_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowCsrPrivateKeyResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'private_key': 'str'
    }

    attribute_map = {
        'private_key': 'private_key'
    }

    def __init__(self, private_key=None):
        """ShowCsrPrivateKeyResponse

        The model defined in huaweicloud sdk

        :param private_key: 私钥。
        :type private_key: str
        """
        
        super(ShowCsrPrivateKeyResponse, self).__init__()

        self._private_key = None
        self.discriminator = None

        if private_key is not None:
            self.private_key = private_key

    @property
    def private_key(self):
        """Gets the private_key of this ShowCsrPrivateKeyResponse.

        私钥。

        :return: The private_key of this ShowCsrPrivateKeyResponse.
        :rtype: str
        """
        return self._private_key

    @private_key.setter
    def private_key(self, private_key):
        """Sets the private_key of this ShowCsrPrivateKeyResponse.

        私钥。

        :param private_key: The private_key of this ShowCsrPrivateKeyResponse.
        :type private_key: str
        """
        self._private_key = private_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowCsrPrivateKeyResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkscm-3.1.149-py2.py3-none-any.whl: huaweicloudsdkscm/v3/model/show_csr_private_key_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowCsrPrivateKeyResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'private_key': 'str'
    }

    attribute_map = {
        'private_key': 'private_key'
    }

    def __init__(self, private_key=None):
        r"""ShowCsrPrivateKeyResponse

        The model defined in huaweicloud sdk

        :param private_key: 私钥。
        :type private_key: str
        """
        
        super(ShowCsrPrivateKeyResponse, self).__init__()

        self._private_key = None
        self.discriminator = None

        if private_key is not None:
            self.private_key = private_key

    @property
    def private_key(self):
        r"""Gets the private_key of this ShowCsrPrivateKeyResponse.

        私钥。

        :return: The private_key of this ShowCsrPrivateKeyResponse.
        :rtype: str
        """
        return self._private_key

    @private_key.setter
    def private_key(self, private_key):
        r"""Sets the private_key of this ShowCsrPrivateKeyResponse.

        私钥。

        :param private_key: The private_key of this ShowCsrPrivateKeyResponse.
        :type private_key: str
        """
        self._private_key = private_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowCsrPrivateKeyResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
